@@ -16,7 +16,7 @@ __copyright__ = "2017 Rodrigo E. Principe"
 try:
     from . import tools, bitreader, cloud_mask, expressions, decision_tree,\
                   filters, indices, batch, algorithms, composite,\
-                  manager, utils, collection, oauth
+                  manager, utils, collection, oauth, visualization
     from .ui import eprint
     from .tools.imagecollection import wrapper
     from .batch import Export, Import, Convert, Download
